changeset 88614:9d51a704ad69

Add coding tag. (tit-process-header): Add coding tag to output.
author Dave Love <fx@gnu.org>
date Thu, 23 May 2002 18:17:35 +0000
parents cb347c3671eb
children fc355fbbbbcc
files lisp/international/titdic-cnv.el
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/titdic-cnv.el	Thu May 23 18:17:21 2002 +0000
+++ b/lisp/international/titdic-cnv.el	Thu May 23 18:17:35 2002 +0000
@@ -1,4 +1,4 @@
 ;;; titdic-cnv.el --- convert cxterm dictionary (TIT format) to Quail package
 
 ;; Copyright (C) 1995 Electrotechnical Laboratory, JAPAN.
 ;; Licensed to the Free Software Foundation.
@@ -267,8 +267,8 @@
 	(tit-keyprompt nil))
 
     (princ ";; Quail package `")
-    (princ package)
-    (princ "' generated by the command `titdic-convert'\n;;\tDate: ")
+    (princ package) (princ "' -*- coding:iso-2022-7bit; -*-\n")
+    (princ ";;   Generated by the command `titdic-convert'\n;;\tDate: ")
     (princ (current-time-string))
     (princ "\n;;\tOriginal TIT dictionary file: ")
     (princ (file-name-nondirectory filename))
@@ -1,4 +1,4 @@
-;;; titdic-cnv.el --- convert cxterm dictionary (TIT format) to Quail package
+;;; titdic-cnv.el --- convert cxterm dictionary (TIT format) to Quail package -*- coding:iso-2022-7bit; -*-
 
 ;; Copyright (C) 1995 Electrotechnical Laboratory, JAPAN.